@@ -114,7 +114,19 @@ ImageInputFormat = Literal["yuv", "rgb", "rgba", "gray"]
 ImageOutputFormat = Literal["rgb", "rgba", "gray"]
 CameraExtension = Literal["hub", "prebuffer", "motionDetection", "objectDetection", "audioDetection", "ptz"]
 CameraFrameWorkerDecoder = Literal["pillow", "wasm"]
-CameraFrameWorkerResolution = Literal["640", "480", "320", "native"]
+CameraFrameWorkerResolution = Literal[
+    "3840x2160",
+    "3072x1728",
+    "2560x1440",
+    "1920x1080",
+    "1440x1080",
+    "1280x720",
+    "960x540",
+    "640x480",
+    "640x360",
+    "320x240",
+    "320x180",
+]
 AudioCodec = Literal["PCMU", "PCMA", "MPEG4-GENERIC", "opus", "G722", "MPA", "PCM", "FLAC"]
 AudioFFmpegCodec = Literal[
     "pcm_mulaw", "pcm_alaw", "aac", "libopus", "g722", "mp3", "pcm_s16be", "pcm_s16le", "flac"
